==========
Change Log
==========

1.1.1 (2019-05-16)
==================

- Fix issue with generating multiple comments (for multiple default values) at
  the end of the YAML config.

- Cast default values when writing to config.


1.1 (2019-05-15)
================

- Allow explicit disabling of automatic config generation.

- Cast default values if a ``cast`` argument is provided.


1.0 (2019-05-15)
================

- Initial Release
